@@ -2040,6 +2040,21 @@ class Update(MethodsInterface):
         ini.delVar('system', 'portage_hash')
         return True
 
+    def save_world_state_hash(self):
+        ini = SystemIni(self.clVars)
+        ps = PortageState()
+        ps.paths = ['/var/lib/portage/world']
+        new_world_state_hash = ps.get_state()
+        ini.setVar('system', {'world_hash': new_world_state_hash})
+
+    def drop_world_state_hash(self):
+        """
+        Сбросить состояние
+        """
+        ini = SystemIni(self.clVars)
+        ini.delVar('system', 'world_hash')
+        return True
+
     def drop_packages_cache(self):
         packages_fn = self.clVars.Get('update.cl_update_package_cache')
         packages_sign_fn = self.clVars.Get('update.cl_update_package_cache_sign')
@@ -2092,7 +2107,7 @@ class Update(MethodsInterface):
             if branch_name == Git.Reference.Tag and tag.isdigit():
                 self._set_saved_tag(tag)
             return True
-        except ValueError as e:
+        except (ValueError, FileNotFoundError) as e:
             return False
 
     def _update_increment_current_level(self):
