@@ -179,8 +179,8 @@ class VariableClUpdateInnerRepList(Variable):
 
     def get(self):
         def gen():
-            val = self.Get('cl_update_rep_list')
-            prev_host = self.Get('cl_update_rep_hosting')
+            val = self.Get('cl_update_rep_list') or ''
+            prev_host = self.Get('cl_update_rep_hosting') or ''
             if prev_host:
                 for dct in val:
                     for key, value in dct.items():
@@ -202,6 +202,7 @@ class VariableClUpdateRepHostingChoice(Variable):
     value = ''
     opt = ["--repo-update"]
     metavalue = "REPOSITORY URL"
+    check_after = ['cl_update_inner_rep_list']
 
     def init(self):
         self.label = (_("Update repository"))
@@ -2091,3 +2092,22 @@ class VariableClUpdateSavedTag(Variable):
 
 class VariableClUpdateSaveCurBinhost(Variable):
     value = " "
+
+
+class VariableClUpdateWorldHashSet(Variable):
+    """
+    Хэш world для проверки изменений
+    """
+    type = Variable.Types.Boolean
+    value = ""
+
+    def get(self):
+        if self.value:
+            return self.value
+        ini = SystemIni(self.parent)
+        old_world_state_hash = ini.getVar('system', 'world_hash') or ""
+        #меняем путь сборки хэша на world файл
+        ps = PortageState()
+        ps.paths = ['/var/lib/portage/world']
+        new_world_state_hash = ps.get_state()
+        return "on" if new_world_state_hash != old_world_state_hash else "off"
